@@ -472,8 +472,8 @@ statesOld<- res[[5]]
 
 # Surveillance started?
 if(start>0){Sn<- sum(cases*w)+sum(cases_old*w_old)}else{if(test==1){Sn<- sum(cases*w)}else{Sn<- sum(cases*w)+sum(cases_old*w_old)}}
-totalevents<- sum(cases)+sum(cases_old)+sum(controls)+sum(controls_old)
-if(start==0){if(actualspent>0|totalevents>=M){start<- test}}             
+
+if(start==0){if(actualspent>0){start<- test}}             
 
 # H0 rejected?
 if(Tailed==1){
@@ -743,7 +743,7 @@ lines(seq(1,test), result[2:(test+1),6],col="black",lty=1)
 
 ini<- 1
 if(is.na(result[2,11])==TRUE){
-while(is.na(result[ini+1,11])==TRUE&ini<test){ini<- ini+1}; if(ini==test){cvs<- result[ini+1,11]}else{cvs<- rep(0,test-ini+1) ; cvs[1]<- result[ini+1,11]; g1<- 1; for(gg in (ini+1):test){g1<- g1+1; if(is.na(result[gg+1,11])==TRUE){cvs[g1]<-result[gg,11]}else{cvs[g1]<-result[gg+1,11] }}}
+while(is.na(result[ini+1,11])==TRUE){ini<- ini+1}; if(ini==test){cvs<- result[ini+1,11]}else{cvs<- rep(0,test-ini+1) ; cvs[1]<- result[ini+1,11]; g1<- 1; for(gg in (ini+1):test){g1<- g1+1; if(is.na(result[gg+1,11])==TRUE){cvs[g1]<-result[gg,11]}else{cvs[g1]<-result[gg+1,11] }}}
 cvs<- as.numeric(cvs)
 points(seq(ini,test),cvs ,col="red",pch=20)
 lines(seq(ini,test), cvs,col="red",lty=1) 
@@ -978,7 +978,7 @@ lines(seq(1,test), result[2:(test+1),6],col="black",lty=1)
 
 ini<- 1
 if(is.na(result[2,11])==TRUE){
-while(is.na(result[ini+1,11])==TRUE&ini<test){ini<- ini+1}; if(ini==test){cvs<- result[ini+1,11]}else{cvs<- rep(0,test-ini+1) ; cvs[1]<- result[ini+1,11]; g1<- 1; for(gg in (ini+1):test){g1<- g1+1; if(is.na(result[gg+1,11])==TRUE){cvs[g1]<-result[gg,11]}else{cvs[g1]<-result[gg+1,11] }}}
+while(is.na(result[ini+1,11])==TRUE){ini<- ini+1}; if(ini==test){cvs<- result[ini+1,11]}else{cvs<- rep(0,test-ini+1) ; cvs[1]<- result[ini+1,11]; g1<- 1; for(gg in (ini+1):test){g1<- g1+1; if(is.na(result[gg+1,11])==TRUE){cvs[g1]<-result[gg,11]}else{cvs[g1]<-result[gg+1,11] }}}
 cvs<- as.numeric(cvs)
 points(seq(ini,test),cvs ,col="red",pch=20)
 lines(seq(ini,test), cvs,col="red",lty=1) 
@@ -1214,7 +1214,7 @@ lines(seq(1,test), result[2:(test+1),6],col="black",lty=1)
 
 ini<- 1
 if(is.na(result[2,11])==TRUE){
-while(is.na(result[ini+1,11])==TRUE&ini<test){ini<- ini+1}; if(ini==test){cvs<- result[ini+1,11]}else{cvs<- rep(0,test-ini+1) ; cvs[1]<- result[ini+1,11]; g1<- 1; for(gg in (ini+1):test){g1<- g1+1; if(is.na(result[gg+1,11])==TRUE){cvs[g1]<-result[gg,11]}else{cvs[g1]<-result[gg+1,11] }}}
+while(is.na(result[ini+1,11])==TRUE){ini<- ini+1}; if(ini==test){cvs<- result[ini+1,11]}else{cvs<- rep(0,test-ini+1) ; cvs[1]<- result[ini+1,11]; g1<- 1; for(gg in (ini+1):test){g1<- g1+1; if(is.na(result[gg+1,11])==TRUE){cvs[g1]<-result[gg,11]}else{cvs[g1]<-result[gg+1,11] }}}
 cvs<- as.numeric(cvs)
 points(seq(ini,test),cvs ,col="red",pch=20)
 lines(seq(ini,test), cvs,col="red",lty=1) 
@@ -1454,7 +1454,7 @@ lines(seq(1,test), result[2:(test+1),6],col="black",lty=1)
 
 ini<- 1
 if(is.na(result[2,11])==TRUE){
-while(is.na(result[ini+1,11])==TRUE&ini<test){ini<- ini+1}; if(ini==test){cvs<- result[ini+1,11]}else{cvs<- rep(0,test-ini+1) ; cvs[1]<- result[ini+1,11]; g1<- 1; for(gg in (ini+1):test){g1<- g1+1; if(is.na(result[gg+1,11])==TRUE){cvs[g1]<-result[gg,11]}else{cvs[g1]<-result[gg+1,11] }}}
+while(is.na(result[ini+1,11])==TRUE){ini<- ini+1}; if(ini==test){cvs<- result[ini+1,11]}else{cvs<- rep(0,test-ini+1) ; cvs[1]<- result[ini+1,11]; g1<- 1; for(gg in (ini+1):test){g1<- g1+1; if(is.na(result[gg+1,11])==TRUE){cvs[g1]<-result[gg,11]}else{cvs[g1]<-result[gg+1,11] }}}
 cvs<- as.numeric(cvs)
 points(seq(ini,test),cvs ,col="red",pch=20)
 lines(seq(ini,test), cvs,col="red",lty=1) 
@@ -1854,21 +1854,11 @@ invisible(result2)
 ####
 #    Note: cut off the symbol "#" before runing the lines below.
 
-#AnalyzeSetUp.Binomial(name="test",N=25, alpha=0.05, pp=0.44, M=5, AlphaSpendType="power-type", rho=0.5,address="C:/Users/Visitante/Ivair/POST-DOC/Material para construcao do pacote Sequential/PASTA PARA TREINO")
+#AnalyzeSetUp.Binomial(name="test",N="n", alpha=0.05, pp=0.44, M=5, AlphaSpendType="optimal",address="C:/Users/ivair/POST-DOC/Material para construcao do pacote Sequential/Sequential_3.0/PASTA PARA TREINO")
 #system.time(res<- Analyze.Binomial(name="test",test=1,p=0.44,cases=6,controls=2))
 
 
 
-# AnalyzeSetUp.Binomial(name="test2",N=25,alpha=0.05,zp=1,pp="n",M=1,AlphaSpendType="Wald",rho="n",title="This is an example of output name",address="C:/Users/Visitante/Ivair/POST-DOC/Material para construcao do pacote Sequential/PASTA PARA TREINO")
-
-#zt<- 1
-#casest<- 5
-#controlst<- 0
-
-#system.time(res<- Analyze.Binomial(name="test2",test=1,z=zt,p="n",cases=casest,controls=controlst))
-
-
-
 
 
 
